ansipen library

Classes

AnsiPen

Constants

ansi_default → const String
ansi_esc → const String
ansiDefault → const String
Reset all colors and options for current SGRs to terminal defaults.
ansiEscape → const String
ANSI Control Sequence Introducer, signals the terminal for new settings.
ansiResetBackground → const String
Ansi codes that default the terminal's background color without altering the foreground, when printed.
ansiResetForeground → const String
Ansi codes that default the terminal's foreground color without altering the background, when printed.

Properties

ansiColorDisabled bool
Globally enable or disable AnsiPen settings.
getter/setter pair
color_disabled bool
getter/setter pair