QuectoPlain class final

Known-plain fast path stylers — ZERO ESC scanning. Use when the caller guarantees the input string contains no nested ANSI escape codes (i.e., it's plain text or a literal string). Access via QuectoPlain.red('Hello').

Constructors

QuectoPlain()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

bgBlack QuectoStyler
set background color to ANSI color black black (0x000000)/rgb(0, 0, 0)
final
bgBlue QuectoStyler
set background color to ANSI color blue blue (0x000088)/rgb(0, 0, 136)
final
bgBlueBright QuectoStyler
set background color to ANSI color brightBlue brightBlue (0x0000FF)/rgb(0, 0, 255)
final
bgCyan QuectoStyler
set background color to ANSI color cyan cyan (0x008888)/rgb(0, 136, 136)
final
bgCyanBright QuectoStyler
set background color to ANSI color brightCyan brightCyan (0x00FFFF)/rgb(0, 255, 255)
final
bgGray QuectoStyler
set background color to ANSI color gray (brightBlack) gray (0x888888)/rgb(136, 136, 136)
final
bgGreen QuectoStyler
set background color to ANSI color green green (0x008800)/rgb(0, 136, 0)
final
bgGreenBright QuectoStyler
set background color to ANSI color brightGreen brightGreen (0x00FF00)/rgb(0, 255, 0)
final
bgGrey QuectoStyler
set background color to ANSI color grey (brightBlack) grey (0x888888)/rgb(136, 136, 136) (alternate spelling for gray)
final
bgMagenta QuectoStyler
set background color to ANSI color magenta magenta (0x880088)/rgb(136, 0, 136)
final
bgMagentaBright QuectoStyler
set background color to ANSI color brightMagenta brightMagenta (0xFF00FF)/rgb(255, 0, 255)
final
bgRed QuectoStyler
set background color to ANSI color red red (0x880000)/rgb(136, 0, 0)
final
bgRedBright QuectoStyler
set background color to ANSI color brightRed brightRed (0xFF0000)/rgb(255, 0, 0)
final
bgWhite QuectoStyler
set background color to ANSI color white white (0x888888)/rgb(136, 136, 136)
final
bgWhiteBright QuectoStyler
set background color to ANSI color brightWhite brightWhite (0xFFFFFF)/rgb(255, 255, 255)
final
bgYellow QuectoStyler
set background color to ANSI color yellow yellow (0x888800)/rgb(136, 136, 0)
final
bgYellowBright QuectoStyler
set background color to ANSI color brightYellow brightYellow (0xFFFF00)/rgb(255, 255, 0)
final
black QuectoStyler
set foreground color to ANSI color black black (0x000000)/rgb(0, 0, 0)
final
final
blue QuectoStyler
set foreground color to ANSI color blue blue (0x000088)/rgb(0, 0, 136)
final
blueBright QuectoStyler
set foreground color to ANSI color brightBlue brightBlue (0x0000FF)/rgb(0, 0, 255)
final
bold QuectoStyler
final
cyan QuectoStyler
set foreground color to ANSI color cyan cyan (0x008888)/rgb(0, 136, 136)
final
cyanBright QuectoStyler
set foreground color to ANSI color brightCyan brightCyan (0x00FFFF)/rgb(0, 255, 255)
final
dim QuectoStyler
final
gray QuectoStyler
set foreground color to ANSI color gray (brightBlack) gray (0x888888)/rgb(136, 136, 136)
final
green QuectoStyler
set foreground color to ANSI color green green (0x008800)/rgb(0, 136, 0)
final
greenBright QuectoStyler
set foreground color to ANSI color brightGreen brightGreen (0x00FF00)/rgb(0, 255, 0)
final
grey QuectoStyler
set foreground color to ANSI color grey (brightBlack) grey (0x888888)/rgb(136, 136, 136) (alternate spelling for gray)
final
hidden QuectoStyler
final
inverse QuectoStyler
final
italic QuectoStyler
final
magenta QuectoStyler
set foreground color to ANSI color magenta magenta (0x880088)/rgb(136, 0, 136)
final
magentaBright QuectoStyler
set foreground color to ANSI color brightMagenta brightMagenta (0xFF00FF)/rgb(255, 0, 255)
final
onBlack QuectoStyler
final
onBlue QuectoStyler
final
onBlueBright QuectoStyler
final
onCyan QuectoStyler
final
onCyanBright QuectoStyler
final
onGray QuectoStyler
final
onGreen QuectoStyler
final
onGreenBright QuectoStyler
final
onGrey QuectoStyler
final
onMagenta QuectoStyler
final
onMagentaBright QuectoStyler
final
onRed QuectoStyler
final
onRedBright QuectoStyler
final
onWhite QuectoStyler
final
onWhiteBright QuectoStyler
final
onYellow QuectoStyler
final
onYellowBright QuectoStyler
final
overline QuectoStyler
final
final
red QuectoStyler
set foreground color to ANSI color red red (0x880000)/rgb(136, 0, 0)
final
redBright QuectoStyler
set foreground color to ANSI color brightRed brightRed (0xFF0000)/rgb(255, 0, 0)
final
reset QuectoStyler
final
strikethrough QuectoStyler
final
subscript QuectoStyler
final
superscript QuectoStyler
final
underline QuectoStyler
final
white QuectoStyler
set foreground color to ANSI color white white (0x888888)/rgb(136, 136, 136)
final
whiteBright QuectoStyler
set foreground color to ANSI color brightWhite brightWhite (0xFFFFFF)/rgb(255, 255, 255)
final
yellow QuectoStyler
set foreground color to ANSI color yellow yellow (0x888800)/rgb(136, 136, 0)
final
yellowBright QuectoStyler
set foreground color to ANSI color brightYellow brightYellow (0xFFFF00)/rgb(255, 255, 0)
final

Static Methods

ansi256(int code) QuectoStyler
bgAnsi256(int code) QuectoStyler
bgRgb(int r, int g, int b) QuectoStyler
createPlainExtendedStyler(String openCode, int ansiClose) QuectoStyler
Creates a plain styler for extended ANSI codes (256-color, 16M truecolor). No ESC scanning, no nesting support. Maximum speed for known-plain text.
createPlainStyler(int ansiOpen, int ansiClose) QuectoStyler
Creates a plain styler that just wraps the string with open/close codes. No ESC scanning, no nesting support. Maximum speed for known-plain text.
onAnsi256(int code) QuectoStyler
onRgb(int r, int g, int b) QuectoStyler
rgb(int r, int g, int b) QuectoStyler
underlineAnsi256(int code) QuectoStyler
underlineRgb(int r, int g, int b) QuectoStyler